// ****************************************************************************
// copyright (c) 2000-2005 Horst Knorr <hk_classes@knoda.org>  
// This file is part of the hk_kdeclasses library.
// This file may be distributed and/or modified under the terms of the
// GNU Library Public License version 2 as published by the Free Software
// Foundation and appearing in the file LGPL included in the
// packaging of this file.
// This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
// WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
// ****************************************************************************

#ifndef HK_KDEQBEPARTFACTORY
#define HK_KDEQBEPARTFACTORY
#include "hk_kdeqbepart.h"
//defining the factory
typedef KParts::GenericFactory<hk_kdeqbepart> hk_kdeqbepartfactory;
K_EXPORT_COMPONENT_FACTORY( libhk_kdeqbepart, hk_kdeqbepartfactory )
#endif
